<?php return array(
	'upcoming milestones in next 30 days' => 'Próximos hitos (en los próximos 30 días)',
	'show all upcoming milestones' => 'Mostrar todos los hitos (total {0})',
	'recent activities' => 'Actividades recientes',
	'search button caption' => 'Buscar',
	'search result description' => 'Mostrando <strong>{0} de {1}</strong> objetos que coinciden con <strong>"{2}"</strong>',
	'search result description short' => '<strong>{0} a {1} de {2}</strong>',
	'edit this file' => 'Editar contenido del archivo',
	'file contents' => 'Contenidos del documento',
	'important message desc' => 'Las notas importantes se encuentran en la barra del costado de la página de notas del espacio, listados bajo el nombre "Notas importantes"',
	'important file desc' => 'Los documentos importantes son listados en la barra del costado, bajo el nombre de "Documentos importantes"',
	'enable comments' => 'Habilitar uso de comentarios',
	'enable comments desc' => 'Los usuarios que puedan ver este comentario, también podrán publicar comentarios. Elija "No" para bloquear los comentarios.',
	'enable anonymous comments' => 'Comentario anónimo',
	'enable anonymous comments desc' => 'Permite comentarios anónimos. Comentarios anónimos pueden ser cargados a traves de la API o a traves de otras formas externas. El autor debe proveer de un nombre y una dirección de correo válidas. La dirección de IP de la fuente será adquirida para el incio de sesión.',
	'completed task' => 'Tarea completada',
	'completed tasks' => 'Tareas completadas',
	'completed subtasks' => 'Subtareas completas',
	'open task' => 'Abrir tarea',
	'open tasks' => 'Abrir tareas',
    'open subtasks' => 'Subtareas pendientes',
	'view all completed tasks' => 'Mostrar todas las tareas completadas (total {0})',
	'recently completed tasks' => 'Mostrar tareas completadas recienmtemente',
	'task open of total tasks' => '{0} abiertas de {1} tareas en la lista',
	'subtask of' => 'Subtarea de: <a class="internalLink" href="{0}">{1}</a>',
	'read more' => 'Leer más &raquo;',
	'message separator' => '<p>* * *</p>',
	'comments on message' => '{0} comentario(s)',
	'comment on object' => 'Comentario \'{0}\' del tema \'{1}\'',
	'revisions on file' => '{0} revisión(es)',
	'message posted on by linktitle' => 'Publicado el {0} por {1}',
	'comment posted on by linktitle' => 'Publicado el {0} por {1}',
	'message posted on by' => 'Publicado el {0} por <a class="internalLink" href="{1}">{2}</a>',
	'comment posted on' => 'Publicado el {0}',
	'comment posted on by' => 'Publicado el {0} por <a class="internalLink" href="{1}">{2}</a>',
	'completed on by' => '{0} | <a class="internalLink" href="{1}">{2}</a>',
	'started on by' => '{0} | <a class="internalLink" href="{1}">{2}</a>',
	'posted on by' => '{0} | <a class="internalLink" href="{1}">{2}</a>',
	'milestone assigned to' => 'Asignado a {0}',
	'assigned to' => 'Asignado a',
	'assigned by' => 'Asignado por',
	'to start' => 'Fecha de comienzo',
	'work performed' => 'Trabajo realizado',
	'project started on' => 'Comenzado el',
	'send milestone assigned to notification' => 'Enviar notificación al usuario asignado vía mail',
	'send task assigned to notification' => 'Enviar notificación al usuario asignado vía mail',
	'send task subscribers notification' => 'Enviar notificación a los suscriptores vía correo electrónico',
	'send email notification' => 'Enviar notificación vía mail',
	'edit company data' => '<a class="internalLink" href="{0}">Edit</a> Datos de la organización',
	'company users involved in project' => '{0} usuarios relacionados en {1}',
	'companies involved in project' => 'Organizaciones relacionadas',
	'tags used on projects' => 'Etiquetas usadas en este espacio',
	'number of tagged objects' => '{0} objeto(s)',
	'total objects tagged with' => 'Hay <b>{0}</b> objetos etiquetados <b>{1}</b> en este espacio',
	'no objects tagged with' => 'No hay objetos etiquetados con <b>{0}</b> en este espacio',
	'tags widget description' => 'Lista de etiquetas separadas por una coma (example: "interface, javascript, public beta")',
	'project permissions form hint' => 'Usando <a class="internalLink" href="{0}">formularios de permisos</a> puede fácilmente agregar o eliminar organizaciones y usuarios y controlar sus permisos de acceso.',
	'expand additional text' => 'Expandir',
	'collapse additional text' => 'Contraer',
	'email notification' => 'Notificación de correo',
	'email notification desc' => 'Notificar y subscribir a esta nota a las personas seleccionadas vía mail',
	'assign milestone task list desc' => 'La tarea puede ser asignada a un hito existente',
	'link existing object' => 'Vincular objeto existente (de la selección de documentos)',
	'upload and link' => 'Cargar documento nuevo y ajuntarlo al objeto',
	'file permissions description' => 'Seleccione un usuario. Luego presione Agregar usuario para visualizarlo en la tabla. <br> Cuando lo vea, seleccione los permisos apropiados en la tabla.<br>Nota: Se mostraran solo los usuarios con los cuales se comparten documentos.',
	'subscribers desc' => 'Los subscriptos recibirán una notificación vía correo siempre que alguien (sin ser ellos mismos) publique un comentario en este objeto',
	'admins can post comments on locked objects desc' => '<strong>Comentarios han sido bloqueados</strong>, pero siendo usted el administrador aún tiene permisos para realizar comentarios. Tenga en cuenta que para recibir respuestas en su publicación deberá desbloquear los comentarios de este objeto <i>(Modifique el campo "Habilitar comentarios" a "Sí")</i>.',
	'all permissions' => 'Todos',
	'can manage messages' => 'Administrar notas',
	'can manage tasks' => 'Puede administrar tareas, asignar y completar tareas de otros',
	'can manage milestones' => 'Administrar hitos',
	'can upload files' => 'Cargar documentos',
	'can manage files' => 'Administrar documentos',
	'can assign to owners' => 'Asignar tareas a miembros de la organización dueño',
	'can assign to other' => 'Asignar tareas a miembros de otros clientes',
	'can manage properties' => 'Administrar propiedades',
	'can manage events' => 'Administrar eventos',
	'add by' => 'agregado por',
	'edit by' => 'modificado por',
	'delete by' => 'eliminado por',
	'close by' => 'cerrado por',
	'open by' => 'abierto por',
	'upload by' => 'cargado por',
	'created by' => 'Creado por',
	'project description' => 'Descripción',
	'project status' => 'Estado del espacio',
	'show project desciption in overview' => '¿Desea mostrar una descripción en la pagina de resumen del espacio?',
	'new file' => 'Documento nuevo',
	'existing file' => 'Documento existente',
	'replace file description' => 'Puede reemplazar un documento existente, al elegir uno nuevo. Si no desea esto, deje en blanco este campo.',
	'download history' => 'Descargar historial',
	'download history for' => 'Descargar historial para <a class="internalLink" href="{0}">{1}</a>',
	'downloaded by' => 'Descargado por',
	'downloaded on' => 'Descargado el',
	'order by filename' => 'Nombre del documento (a-z)',
	'order by posttime' => 'Fecha y hora',
	'all files' => 'Todos los documentos',
	'upload file desc' => 'Pude cargar documentos de cualquier tipo. El tamaño máximo permitido para cargar documentos es {0}',
	'file revision info short' => 'Revisión #{0} <span>(creada el {1})</span>',
	'file revision info long' => 'Revisión #{0} <span>(por <a class="internalLink" href="{1}">{2}</a> el {3})</span>',
	'file revision title short' => 'Creada el {0}',
	'file revision title long' => '<b><a class="internalLink" href="{0}">{1}</a></b>, el {2}',
	'file checkout info short' => '<span>Revisado el {0}</span>',
	'file checkout info long' => '<span>Revisado por </span> <a class="internalLink" href="{0}">{1}</a> <span> el {2}</span>',
	'update file' => 'Actualizar documento',
	'version file change' => 'Recordar cambios (el documento anterior será guardado como referencia)',
	'last revision' => 'Ultima revisión',
	'revision comment' => 'Comentario de la revisión',
	'edit revision comment' => 'Editar el comentario de la revisión',
	'initial versions' => '-- Versión inicial --',
	'file details' => 'Detalles del documento',
	'view file details' => 'Ver detalles del documento',
	'add link object control' => 'Agregar',
	'remove link object control' => 'Eliminar',
	'link objects to object desc' => 'Use este formulario para vincular objetos a <strong><a href="{0}">{1}</a></strong>. Es posible vincular uno o más de un objeto. Puede elegir un objeto existente, o cargar otros. <strong>Los objetos nuevos, despues de ser cargados, estarán disponibles en la sección de documentos</strong>.',
	'select object' => 'Elija un objeto',
	'admin notice comments disabled' => 'Los comentarios han sido bloqueados para este objeto, aun así un administrador puede comentar en él. Si espera respuestas, no olvide habilitar comentarios por otros.',
	'icalendar' => 'iCalendario',
	'icalendar subscribe' => 'iCalendario',
	'icalendar subscribe desc' => 'Use esta opción para disponer de los datos del hito en su una aplicación de calendario.',
	'icalendar password change notice' => '<strong>Nota:</strong> si modifica su contraseña, el vínculo al calendario también será modificado. Precisará suscribirse nuevamente.',
	'success message' => 'Mensaje de éxito',
	'project form action' => 'Acción',
	'project form action add comment' => 'Agregar comentario',
	'project form action add task' => 'Agregar tarea',
	'project form enabled' => 'Habilitado',
	'project form visible' => 'Visible',
	'add comment to message' => 'Agregar comentario a <a class="internalLink" href="{0}">{1}</a>',
	'add comment to message short' => 'para',
	'add task to list' => 'Agregar tarea a <a class="internalLink" href="{0}">{1}</a>',
	'add task to list short' => 'para',
	'private message desc' => 'Las notas privadas son sólamente visibles por los miembros de la organización dueña. Miembros de organizaciones clientes no podrán verlos.',
	'private webpage desc' => 'Los vínculos web privados son sólamente visibles por los miembros de la organización dueña. Miembros de organizaciones clientes no podrán verlos.',
	'private milestone desc' => 'Los hitos privados son sólamente visibles por los miembros de la organización dueña. Miembros de organizaciones clientes no podrán verlos.',
	'private task list desc' => 'Las tareas privadas son sólamente visibles por los miembros de la organización dueña. Miembros de organizaciones clientes no podrán verlos.',
	'private comment desc' => 'Los comentarios privados son sólamente visibles por los miembros de la organización dueña. Miembros de organizaciones clientes no podrán verlos.',
	'private file desc' => 'Los documentos privados son sólamente visibles por los miembros de la organización dueña. Miembros de organizaciones clientes no podrán verlos.',
	'select a tag' => 'Elija etiqueta...',
	'select a user' => 'Elija un usuario...',
	'select a project' => 'Elija un espacio...',
	'upload a file' => 'Cargue un documento',
	'upload project desc' => 'Espacio donde se guardará el documento cargado',
	'upload tag desc' => 'Aquí puede elegir una etiqueta existente o crear una nueva. Luego de elegir una etiqueta presione Enter para agregar otra.',
	'upload permissions desc' => 'Elija los usuarios habilitados para acceder a este documento. De forma análoga a las etiquetas, escriba o elija un nombre de usuario, y luego presione enter para seguir agregando usuarios.',
	'upload description desc' => 'Escriba la descripción del documento',
	'uploading file' => 'Cargando documento...',
	'cannot delete personal project' => 'El espacio personal no puede ser eliminado',
	'workspace color' => 'Color del espacio',
	'field workspace color' => 'Color del espacio',
	'workspace template' => 'Template del espacio',
	'color1' => 'Rojo',
	'color2' => 'Verde',
	'color3' => 'Azul',
	'color4' => 'Amarillo',
	'color5' => 'Anaranjado',
	'color6' => 'Magenta',
	'color7' => 'Cián',
	'color8' => 'Violeta',
	'choose a color' => 'Elija un color',
	'show more' => 'Ver más',
	'show more amount' => 'Ver más ({0})',
	'new contact' => 'Persona nueva',
	'work' => 'Trabajo',
	'home' => 'Casa',
	'other' => 'Otro',
	'display' => 'Desplegar',
	'display options' => 'Desplegar opciones',
	'show in project' => 'Mostrar en el espacio',
	'show in project desc' => 'Mostrar en el panel de descripción general del espacio',
	'show in parents' => 'Mostrar en los padres',
	'show in parents desc' => 'Mostrar en el panel de descripción general de cada espacio selaccionado',
	'reporting' => 'Reportes',
	'chart' => 'Gráfico',
	'new chart' => 'Nuevo gráfico',
	'add chart' => 'Agregar gráfico',
	'edit chart' => 'Editar gráfico',
	'delete chart' => 'Eliminar gráfico',
	'ObjectTypeCount' => 'Cantidades de objeto por tipo',
	'TasksByDueDate' => 'Tareas personales ordenadas por fecha límite',
	'BudgetExecution' => 'Ejecución del presupuesto',
	'BudgetExecutionTrack' => 'Ejecución del presupuesto por mes',
	'MonthlyBudgetExecution' => 'Ejecución del presupuesto del presente mes',
	'bars chart' => 'Barras',
	'pie chart' => 'Torta',
	'lines chart' => 'Líneas',
	'draw chart' => 'Dibujar',
	'chart display' => 'Desplegar',
	'bar sketch' => 'Sketch de barras',
	'bar 3d' => 'Barras de 3d',
	'bar glass' => 'Barras transparentes',
	'budgeted' => 'Presupuestado',
	'current' => 'Actual',
	'executed' => 'Ejecutado',
	'not executed' => 'No ejecutado',
	'success deleted chart' => 'Gráfico \'{0}\' eliminado satisfactoriamente',
	'error deleted chart' => 'Un error ha ocurrido al eliminar el gráfico',
	'task priority' => 'Prioridad',
	'high priority' => 'Alta',
	'normal priority' => 'Normal',
	'low priority' => 'Baja',
	'estimated time' => 'Estimación de tiempo',
	'estimated time desc' => 'Duración estimada de la tarea en horas.',
	'x hours' => '{0} horas.',
	'pending' => 'Pendiente',
	'pending pl' => 'Pendientes',
	'new task template' => 'Nueva plantilla de tareas',
	'new task from template' => 'Nueva tarea desde plantilla',
	'save as template' => 'Guardar como plantilla',
	'save template' => 'Guardar plantilla',
	'delete template' => 'Borrar plantilla',
	'variables' => 'Variables',
	'add a variable to this template' => 'Agregar parámetro a esta plantilla',
	'add a new task to this template' => 'Agregar una nueva tarea a esta plantilla',
	'add a new milestone to this template' => 'Agregar un nuevo hito a esta plantilla',
	'new milestone template' => 'Nueva plantilla de hito',
	'new milestone from template' => 'Nuevo hito desde plantilla',
	'loading' => 'Cargando',
	'show all' => 'Mostrar todos',
	'unassigned' => 'No asignadas',
	'latest comments' => 'Últimos comentarios',
	'include unworked pending tasks' => 'Incluir tareas pendientes no trabajadas',
	'unworked pending tasks' => 'Tareas pendientes no trabajadas',
	'email sent by linktitle' => 'Enviado por {1}, {0}',
	'assign contact to workspace desc' => 'Para asignar un contacto a un espacio marque el espacio y luego ingrese el rol en el campo de texto.',
	'edit task template' => 'Editar planitlla de tarea',
	'cannot change parent workspace' => 'Usted no tiene permisos suficientes para cambiar el padre de este espacio de trabajo.',
	'cannot change parent workspace description' => 'Este espacio de trabajo puede pertenecer a un espacio al cual ud. no tiene acceso.',
	'copy of file' => 'Copia de {0}',
	'add subscribers desc' => 'Las personas seleccionadas serán subscriptas a este objeto. Usuarios suscritos recibirán correos electrónicos acerca de modificaciones a este objeto.',
	'add custom property' => 'Agregar propiedad personalizada',
	'fetch imap folders' => 'Obtener carpetas IMAP',
	'no reports found' => 'No se encontraron reportes para {0}',
	'remove this widget' => 'Quitar este widget',
	'add a new' => 'Agregar un nuevo',
	'other settings' => 'Otros',
	'incoming settings' => 'Configuración entrante',
	'default account' => 'Cuenta por defecto',
	'default account description' => 'La cuenta por defecto es la utilizada cuando compone un nuevo correo.',
	'signature' => 'Firma',
	'signature description' => 'Esta firma se agregará automáticamente a todos los correos enviados desde esta cuenta.',
	'attach contents' => 'Adjuntar contenido',
	'set parent task' => 'Elegir tarea padre',
	'create task from email' => 'Crear tarea de este correo',
	'create task from email description' => 'De:       {1}<br/>
Asunto:   {0}<br/>
<br/>
{2}',
	'suggested workspaces' => 'Espacios de trabajo sugeridos',
	'mail account sender name' => 'Nombre del emisor',
	'mail account sender name description' => 'Nombre a usar en el campo "De" cuando se envía un correo. Si se deja en blanco se utilizará el nombre del usuario por defecto.',
	'classify mails on workspace' => 'Autoclasificar',
	'classify mails on workspace desc' => 'Si se selecciona un espacio, todos los correos entrantes se clasificarán automáticamente en dicho espacio.',
	'mail account permissions' => 'Permisos de la cuenta',
	'cannot access account' => 'Sin acceso',
	'can view account emails' => 'Puede leer/escribir correos',
	'can view account emails and edit' => 'Puede leer/escribir correos y editar la cuenta',
	'personal settings' => 'Configuración personal',
	'personal settings desc' => 'Esta configuración es específica a su usuario y no afectará a otros usuarios con acceso a esta cuenta.',
	'add milestone change workspace warning' => '¡ADVERTENCIA! Las tareas de este hito deben pertenecer al mismo espacio de trabajo que el hito, o a uno de sus sub-espacios. Si el espacio es cambiado, cualquier tarea que no cumpla con esta regla será movida a ese espacio.',
	'update unset billing values' => 'Actualizar tiempos de trabajo que no tienen valores de facturación',
	'update unset billing values desc' => 'NOTA: Esta accion aplica los nuevos valores de facturación a todos los tiempos de trabajo sin horas de facturación. ¿Desea proceder?',
	'field title' => 'Título',
	'field text' => 'Texto',
	'field email' => 'Correo',
	'field from' => 'De',
	'field to' => 'Para',
	'field subject' => 'Asunto',
	'field comment' => 'Comentario',
	'field email2' => 'Correo secundario',
	'field body_plain' => 'Cuerpo',
	'field from_name' => 'De',
	'field firstname' => 'Nombre',
	'field lastname' => 'Apellido',
	'field filecontent' => 'Contenido',
	'field uid' => 'ID único',
	'field h_address' => 'Dirección casa',
	'field w_address' => 'Dirección trabajo',
	'field o_address' => 'Otra dirección',
	'mail account permissions desc' => 'Elija quiénes podrán leer y escribir correos desde esta cuenta, quiénes podrán editar información general de la cuenta y quiénes no tendrán acceso a esta cuenta.<br/><b>Nota:</b> Los correos clasificados en un espacio siempre serán visibles por los usuarios que tengan permiso de lectura sobre el espacio, sin importar estos permisos.',
	'linked main title' => 'Vínculos',
	'linked file tab' => 'Documentos',
	'linked email tab' => 'Correo',
	'linked weblink tab' => 'Vínculos Web',
	'email tab' => 'Correo',
	'linked emailunclassified tab' => 'Correo no clasificado',
	'linked message tab' => 'Notas',
	'linked contact tab' => 'Personas',
	'linked comment tab' => 'Comentarios',
	'linked webpage tab' => 'Enlaces web',
	'linked company tab' => 'Organizaciones',
	'linked milestone tab' => 'Hitos',
	'linked task tab' => 'Tareas',
	'linked event tab' => 'Eventos',
	'linked objective tab' => 'Objetivos',
	'apply assignee to subtasks' => 'Aplicar asignado actual a subtareas',
	'undo remove subtasks' => 'Restaurar las subtareas removidas',
	'urgent priority' => 'Urgente',
	'attachment from email' => 'Adjunto al correo "{0}"',
	'total estimated time' => 'Tiempo estimado total',	

	'emailunclassified' => 'Emails no clasificados',
	'file' => 'Archivos',
	'email' => 'Emails',
	'weblink' => 'Links',
	'message' => 'Notas',
	'contact' => 'Contactos',
	'comment' => 'Comentarios',
	'webpage' => 'Web links',
	'company' => 'Organizaciones',
	'milestone' => 'Hitos',
	'task' => 'Tareas',
	'event' => 'Eventos',
	'objective' => 'Objetivos',
	'form' => 'Formulario',
	'linked object tab' => '{0}',
); ?>
